@@ -220,11 +220,12 @@ class notion_connector:
 		except requests.exceptions.HTTPError as err:
 			self.put_in_file(json.loads(reply.text), 'error.json')
 			print(self.RED + '[NOTION CONNECTOR] ' + str(err) + ' on POST ' + url + self.DEFAULT)
+		line = json.loads(reply.text)
 		data_line = {
-			'page_id' : reply['id'],
+			'page_id' : line['id'],
 			'properties' : {}
 		}
-		for i in reply['properties'].items():
+		for i in line['properties'].items():
 			if i[1]['type'] == 'title':
 				data_line['title'] = self.getProperties(i[1])['value']
 			data_line['properties'][i[0]] = self.getProperties(i[1])
