@@ -27,7 +27,7 @@ class update_properties:
 	# UPDATE ELEMENT
 	def noneUpdate(self, elem):
 		return None
-		
+
 	def update_date(self, elem):
 		if elem['properties']['date'] != None and elem['value_start'] != None:
 			if elem['properties']['date']['start'] != elem['value_start'] or elem['properties']['date']['end'] != elem['value_end']:
@@ -36,6 +36,8 @@ class update_properties:
 			else :
 				return None
 		elif elem['value_start'] != None and elem['properties']['date'] == None:
+			print("ICI")
+			elem['properties']['date'] = {}
 			elem['properties']['date']['start'] = elem['value_start']
 			elem['properties']['date']['end'] = elem['value_end']
 			elem['properties']['date']['time_zone'] = None
